<template>
  <j-modal
    :title="title"
    :width="width"
    :visible="visible"
    :confirmLoading="confirmLoading"
    switchFullscreen
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form-model
        ref="form"
        :model="model"
        :rules="validatorRules"
      >
        <a-row :gutter="24">
          <a-col :span='24'>
            <a-form-model-item 
              label='验收人' 
              prop='errUda3' 
              :labelCol="labelCol"
              :wrapperCol="wrapperCol">
              <a-input v-model='model.errUda3'  
              >
            </a-input>
            </a-form-model-item>
          </a-col>
          <a-col :span="24">
            <a-form-model-item
              label="验收意见"
              :labelCol="labelCol"
              :wrapperCol="wrapperCol"
              prop="errUda5"
            >
               <a-textarea v-model="model.errUda5" rows="4" placeholder="验收意见" />
            </a-form-model-item>
          </a-col>
        </a-row>
      </a-form-model>
    </a-spin>
  </j-modal>
</template>
<script>
import { httpAction } from '@/api/manage'
import { validateDuplicateValue } from '@/utils/util'
import pick from 'lodash.pick'
import { postAction, requestPut, getAction } from '@/api/manage'
import { duplicateCheck } from '@/api/api'
import moment from 'moment'
import { JVxeTableModelMixin } from '@/mixins/JVxeTableModelMixin.js'
import { JVXETypes } from '@/components/jeecg/JVxeTable'
export default {
  name: "NodeModel",
  mixins: [JVxeTableModelMixin],
  components: {
    validateDuplicateValue,
  },
  props: {
    disableSubmit: {
      type: Boolean,
      default: false,
      required: false
    },
    caytegoryParam: {
      type: String,
      default: '',
      required: false
    }
  },
  data() {
    return {
      title: "操作",
      width: 1500,
      visible: false,
      model: {
      },
      labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
      },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
      },

      confirmLoading: false,
      validatorRules: {
        errUda5: [
          {required:true,message:"请输入验收意见"},
          { min: 0, max: 100, message: '长度不超过 100 个字符' },
        ],
        errUda3 :[
          {required:true,message:"请输入名称"},
          { min: 0, max: 10, message: '名称不超过 10 个字符'},
        ],
      },
      url: {
        accept: "/eam/equipmentReportRepair/accept",
      },
    }
  },
  created() {
    //备份model原始值
    this.initOptions();
    this.modelDefault = JSON.parse(JSON.stringify(this.model));
  },
  methods: {
    add() {
      this.edit(this.modelDefault);
    },
    edit(record) {
      this.model = Object.assign({}, record);
      this.visible = true;
    },
    close() {
      this.$emit('close');
      this.visible = false;
      this.$refs.form.clearValidate();
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.$refs.form.validate(valid => {
        if (valid) {
          that.confirmLoading = true;
          let httpurl = this.url.accept;
          let method = 'put';
          httpAction(httpurl, this.model, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    },
  },
  computed: {
    formDisabled() {
      return this.disableSubmit
    },
  },
}
</script>